import re
from setuptools import setup, find_packages

setup(
	name='mudicom',
	version='0.0.1',
	author='Eric Bower',
	author_email='neurosnap@gmail.com',
	packages=find_packages(),
	url='http://pypi.python.org/pypi/mudicom/',
	license='LICENSE',
)
